/* -*- Mode: C++; tab-width: 2; c-basic-offset: 2 -*- */
/*
	pdftk, the PDF Tool Kit
	Copyright (c) 2003, 2004 Sid Steward

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	Visit: http://www.gnu.org/licenses/gpl.txt
	for more details on this license.

	Visit: http://www.pdftk.com for the latest information on pdftk

	Please contact Sid Steward with bug reports:
	ssteward at AccessPDF dot com
*/

void
ReportAcroFormFields( ostream& ofs,
											itext::PdfReader* reader_p );

void
ReportOnPdf( ostream& ofs,
						 itext::PdfReader* reader_p );

bool
UpdateInfo( itext::PdfReader* reader_p,
						istream& ifs );

bool
ReplaceXmp( itext::PdfReader* reader_p,
						string xmp_filename );

bool
UpdateXmp( itext::PdfReader* reader_p,
					 string xmp_filename );

